==> haskell-linear-1.23.2-39.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-3J4aX7wWiR6yJH38PExLK
key:                  linear-1.23.2-3J4aX7wWiR6yJH38PExLK
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  bb8ea55955d9f7794731223d114923f7
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-3J4aX7wWiR6yJH38PExLK
depends:
    adjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ base-4.18.2.1
    base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL binary-0.8.9.1
    bytes-0.17.4-Ie4bIJB4hX13MnlwcfQWOn
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    deepseq-1.4.8.1 distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    ghc-prim-0.10.0 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    reflection-2.1.9-LtSX5qahOBWBJVCTiw5gqi
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.23.2-40-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-L00v0Lq41EK6ZdYCwKhGRn
key:                  linear-1.23.2-L00v0Lq41EK6ZdYCwKhGRn
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  296a236128b964680cc316c01537d2b7
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-L00v0Lq41EK6ZdYCwKhGRn
depends:
    adjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX base-4.18.2.1
    base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL binary-0.8.9.1
    bytes-0.17.4-KxpygW1j5Fd25NrlyaW1Zf
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    deepseq-1.4.8.1 distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    ghc-prim-0.10.0 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    reflection-2.1.9-8Q7I5njAXv0HxAP0gvhFsJ
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
